# coding: utf-8

"""
    Polyaxon SDKs and REST API specification.

         # noqa: E501

    The version of the OpenAPI document: 2.12.0-rc3
    Contact: contact@polyaxon.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Any, Dict, List, Optional
from pydantic import BaseModel, Field, StrictStr, conlist
from polyaxon_sdk.models.v1_ray_replica import V1RayReplica

class V1RayCluster(BaseModel):
    """
    V1RayCluster
    """
    kind: Optional[StrictStr] = 'raycluster'
    entrypoint: Optional[StrictStr] = None
    runtime_env: Optional[Dict[str, Any]] = Field(None, alias="runtimeEnv")
    metadata: Optional[Dict[str, StrictStr]] = None
    ray_version: Optional[StrictStr] = Field(None, alias="rayVersion")
    head: Optional[V1RayReplica] = None
    workers: Optional[conlist(V1RayReplica)] = None
    __properties = ["kind", "entrypoint", "runtimeEnv", "metadata", "rayVersion", "head", "workers"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> V1RayCluster:
        """Create an instance of V1RayCluster from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of head
        if self.head:
            _dict['head'] = self.head.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in workers (list)
        _items = []
        if self.workers:
            for _item in self.workers:
                if _item:
                    _items.append(_item.to_dict())
            _dict['workers'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> V1RayCluster:
        """Create an instance of V1RayCluster from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return V1RayCluster.parse_obj(obj)

        _obj = V1RayCluster.parse_obj({
            "kind": obj.get("kind") if obj.get("kind") is not None else 'raycluster',
            "entrypoint": obj.get("entrypoint"),
            "runtime_env": obj.get("runtimeEnv"),
            "metadata": obj.get("metadata"),
            "ray_version": obj.get("rayVersion"),
            "head": V1RayReplica.from_dict(obj.get("head")) if obj.get("head") is not None else None,
            "workers": [V1RayReplica.from_dict(_item) for _item in obj.get("workers")] if obj.get("workers") is not None else None
        })
        return _obj




# coding: utf-8

"""
    Polyaxon SDKs and REST API specification.

         # noqa: E501

    The version of the OpenAPI document: 2.12.0-rc3
    Contact: contact@polyaxon.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Any, Dict, List, Optional
from pydantic import BaseModel, Field, StrictStr, conlist
from polyaxon_sdk.models.v1_connection_kind import V1ConnectionKind
from polyaxon_sdk.models.v1_connection_resource import V1ConnectionResource

class V1ConnectionType(BaseModel):
    """
    V1ConnectionType
    """
    name: Optional[StrictStr] = None
    description: Optional[StrictStr] = None
    tags: Optional[StrictStr] = None
    kind: Optional[V1ConnectionKind] = None
    var_schema: Optional[Dict[str, Any]] = Field(None, alias="schema")
    secret: Optional[V1ConnectionResource] = None
    config_map: Optional[V1ConnectionResource] = Field(None, alias="configMap")
    env: Optional[conlist(Dict[str, Any])] = None
    annotations: Optional[Dict[str, StrictStr]] = None
    __properties = ["name", "description", "tags", "kind", "schema", "secret", "configMap", "env", "annotations"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> V1ConnectionType:
        """Create an instance of V1ConnectionType from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of secret
        if self.secret:
            _dict['secret'] = self.secret.to_dict()
        # override the default output from pydantic by calling `to_dict()` of config_map
        if self.config_map:
            _dict['configMap'] = self.config_map.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> V1ConnectionType:
        """Create an instance of V1ConnectionType from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return V1ConnectionType.parse_obj(obj)

        _obj = V1ConnectionType.parse_obj({
            "name": obj.get("name"),
            "description": obj.get("description"),
            "tags": obj.get("tags"),
            "kind": obj.get("kind"),
            "var_schema": obj.get("schema"),
            "secret": V1ConnectionResource.from_dict(obj.get("secret")) if obj.get("secret") is not None else None,
            "config_map": V1ConnectionResource.from_dict(obj.get("configMap")) if obj.get("configMap") is not None else None,
            "env": obj.get("env"),
            "annotations": obj.get("annotations")
        })
        return _obj




# coding: utf-8

"""
    Polyaxon SDKs and REST API specification.

         # noqa: E501

    The version of the OpenAPI document: 2.12.0-rc3
    Contact: contact@polyaxon.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Any, Dict, Optional
from pydantic import BaseModel, StrictBool

class AgentStateResponseAgentState(BaseModel):
    """
    AgentStateResponseAgentState
    """
    schedules: Optional[Dict[str, Any]] = None
    hooks: Optional[Dict[str, Any]] = None
    watchdogs: Optional[Dict[str, Any]] = None
    tuners: Optional[Dict[str, Any]] = None
    queued: Optional[Dict[str, Any]] = None
    stopping: Optional[Dict[str, Any]] = None
    deleting: Optional[Dict[str, Any]] = None
    apply: Optional[Dict[str, Any]] = None
    checks: Optional[Dict[str, Any]] = None
    full: Optional[StrictBool] = None
    __properties = ["schedules", "hooks", "watchdogs", "tuners", "queued", "stopping", "deleting", "apply", "checks", "full"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> AgentStateResponseAgentState:
        """Create an instance of AgentStateResponseAgentState from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> AgentStateResponseAgentState:
        """Create an instance of AgentStateResponseAgentState from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return AgentStateResponseAgentState.parse_obj(obj)

        _obj = AgentStateResponseAgentState.parse_obj({
            "schedules": obj.get("schedules"),
            "hooks": obj.get("hooks"),
            "watchdogs": obj.get("watchdogs"),
            "tuners": obj.get("tuners"),
            "queued": obj.get("queued"),
            "stopping": obj.get("stopping"),
            "deleting": obj.get("deleting"),
            "apply": obj.get("apply"),
            "checks": obj.get("checks"),
            "full": obj.get("full")
        })
        return _obj




# coding: utf-8

"""
    Polyaxon SDKs and REST API specification.

         # noqa: E501

    The version of the OpenAPI document: 2.12.0-rc3
    Contact: contact@polyaxon.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import BaseModel, conlist
from polyaxon_sdk.models.v1_settings_catalog import V1SettingsCatalog

class V1TeamSettings(BaseModel):
    """
    V1TeamSettings
    """
    projects: Optional[conlist(V1SettingsCatalog)] = None
    hubs: Optional[conlist(V1SettingsCatalog)] = None
    registries: Optional[conlist(V1SettingsCatalog)] = None
    __properties = ["projects", "hubs", "registries"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> V1TeamSettings:
        """Create an instance of V1TeamSettings from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in projects (list)
        _items = []
        if self.projects:
            for _item in self.projects:
                if _item:
                    _items.append(_item.to_dict())
            _dict['projects'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in hubs (list)
        _items = []
        if self.hubs:
            for _item in self.hubs:
                if _item:
                    _items.append(_item.to_dict())
            _dict['hubs'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in registries (list)
        _items = []
        if self.registries:
            for _item in self.registries:
                if _item:
                    _items.append(_item.to_dict())
            _dict['registries'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> V1TeamSettings:
        """Create an instance of V1TeamSettings from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return V1TeamSettings.parse_obj(obj)

        _obj = V1TeamSettings.parse_obj({
            "projects": [V1SettingsCatalog.from_dict(_item) for _item in obj.get("projects")] if obj.get("projects") is not None else None,
            "hubs": [V1SettingsCatalog.from_dict(_item) for _item in obj.get("hubs")] if obj.get("hubs") is not None else None,
            "registries": [V1SettingsCatalog.from_dict(_item) for _item in obj.get("registries")] if obj.get("registries") is not None else None
        })
        return _obj




# coding: utf-8

"""
    Polyaxon SDKs and REST API specification.

         # noqa: E501

    The version of the OpenAPI document: 2.12.0-rc3
    Contact: contact@polyaxon.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import BaseModel, StrictStr, conlist
from polyaxon_sdk.models.v1_user_access_data import V1UserAccessData

class V1UserAccess(BaseModel):
    """
    V1UserAccess
    """
    user: Optional[StrictStr] = None
    user_data: Optional[V1UserAccessData] = None
    queue: Optional[StrictStr] = None
    default_presets: Optional[conlist(StrictStr)] = None
    default_presets_ordered: Optional[conlist(StrictStr)] = None
    namespace: Optional[StrictStr] = None
    __properties = ["user", "user_data", "queue", "default_presets", "default_presets_ordered", "namespace"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> V1UserAccess:
        """Create an instance of V1UserAccess from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of user_data
        if self.user_data:
            _dict['user_data'] = self.user_data.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> V1UserAccess:
        """Create an instance of V1UserAccess from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return V1UserAccess.parse_obj(obj)

        _obj = V1UserAccess.parse_obj({
            "user": obj.get("user"),
            "user_data": V1UserAccessData.from_dict(obj.get("user_data")) if obj.get("user_data") is not None else None,
            "queue": obj.get("queue"),
            "default_presets": obj.get("default_presets"),
            "default_presets_ordered": obj.get("default_presets_ordered"),
            "namespace": obj.get("namespace")
        })
        return _obj




# coding: utf-8

"""
    Polyaxon SDKs and REST API specification.

         # noqa: E501

    The version of the OpenAPI document: 2.12.0-rc3
    Contact: contact@polyaxon.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Any, Dict, List, Optional
from pydantic import BaseModel, StrictStr, conlist
from polyaxon_sdk.models.v1_status_condition import V1StatusCondition
from polyaxon_sdk.models.v1_statuses import V1Statuses

class V1Status(BaseModel):
    """
    V1Status
    """
    uuid: Optional[StrictStr] = None
    status: Optional[V1Statuses] = None
    status_conditions: Optional[conlist(V1StatusCondition)] = None
    meta_info: Optional[Dict[str, Any]] = None
    __properties = ["uuid", "status", "status_conditions", "meta_info"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> V1Status:
        """Create an instance of V1Status from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in status_conditions (list)
        _items = []
        if self.status_conditions:
            for _item in self.status_conditions:
                if _item:
                    _items.append(_item.to_dict())
            _dict['status_conditions'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> V1Status:
        """Create an instance of V1Status from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return V1Status.parse_obj(obj)

        _obj = V1Status.parse_obj({
            "uuid": obj.get("uuid"),
            "status": obj.get("status"),
            "status_conditions": [V1StatusCondition.from_dict(_item) for _item in obj.get("status_conditions")] if obj.get("status_conditions") is not None else None,
            "meta_info": obj.get("meta_info")
        })
        return _obj




# coding: utf-8

"""
    Polyaxon SDKs and REST API specification.

         # noqa: E501

    The version of the OpenAPI document: 2.12.0-rc3
    Contact: contact@polyaxon.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Any, Dict, List, Optional
from pydantic import BaseModel, Field, StrictBool, StrictStr, conlist
from polyaxon_sdk.models.v1_validation import V1Validation

class V1IO(BaseModel):
    """
    V1IO
    """
    name: Optional[StrictStr] = None
    description: Optional[StrictStr] = None
    type: Optional[StrictStr] = None
    value: Optional[Dict[str, Any]] = None
    is_optional: Optional[StrictBool] = Field(None, alias="isOptional")
    is_list: Optional[StrictBool] = Field(None, alias="isList")
    is_flag: Optional[StrictBool] = Field(None, alias="isFlag")
    arg_format: Optional[StrictStr] = Field(None, alias="argFormat")
    connection: Optional[StrictStr] = None
    to_init: Optional[StrictBool] = Field(None, alias="toInit")
    to_env: Optional[StrictStr] = Field(None, alias="toEnv")
    validation: Optional[V1Validation] = None
    delay_validation: Optional[StrictBool] = Field(None, alias="delayValidation")
    options: Optional[conlist(Dict[str, Any])] = None
    __properties = ["name", "description", "type", "value", "isOptional", "isList", "isFlag", "argFormat", "connection", "toInit", "toEnv", "validation", "delayValidation", "options"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> V1IO:
        """Create an instance of V1IO from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of validation
        if self.validation:
            _dict['validation'] = self.validation.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> V1IO:
        """Create an instance of V1IO from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return V1IO.parse_obj(obj)

        _obj = V1IO.parse_obj({
            "name": obj.get("name"),
            "description": obj.get("description"),
            "type": obj.get("type"),
            "value": obj.get("value"),
            "is_optional": obj.get("isOptional"),
            "is_list": obj.get("isList"),
            "is_flag": obj.get("isFlag"),
            "arg_format": obj.get("argFormat"),
            "connection": obj.get("connection"),
            "to_init": obj.get("toInit"),
            "to_env": obj.get("toEnv"),
            "validation": V1Validation.from_dict(obj.get("validation")) if obj.get("validation") is not None else None,
            "delay_validation": obj.get("delayValidation"),
            "options": obj.get("options")
        })
        return _obj




# coding: utf-8

"""
    Polyaxon SDKs and REST API specification.

         # noqa: E501

    The version of the OpenAPI document: 2.12.0-rc3
    Contact: contact@polyaxon.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Any, Dict, List, Optional
from pydantic import BaseModel, Field, StrictInt, StrictStr, conlist
from polyaxon_sdk.models.v1_component import V1Component
from polyaxon_sdk.models.v1_environment import V1Environment
from polyaxon_sdk.models.v1_operation import V1Operation

class V1Dag(BaseModel):
    """
    V1Dag
    """
    kind: Optional[StrictStr] = 'dag'
    operations: Optional[conlist(V1Operation)] = None
    components: Optional[conlist(V1Component)] = None
    concurrency: Optional[StrictInt] = None
    early_stopping: Optional[conlist(Dict[str, Any])] = Field(None, alias="earlyStopping")
    environment: Optional[V1Environment] = None
    connections: Optional[conlist(StrictStr)] = None
    volumes: Optional[conlist(Dict[str, Any])] = Field(None, description="Volumes is a list of volumes that can be mounted.")
    __properties = ["kind", "operations", "components", "concurrency", "earlyStopping", "environment", "connections", "volumes"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> V1Dag:
        """Create an instance of V1Dag from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in operations (list)
        _items = []
        if self.operations:
            for _item in self.operations:
                if _item:
                    _items.append(_item.to_dict())
            _dict['operations'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in components (list)
        _items = []
        if self.components:
            for _item in self.components:
                if _item:
                    _items.append(_item.to_dict())
            _dict['components'] = _items
        # override the default output from pydantic by calling `to_dict()` of environment
        if self.environment:
            _dict['environment'] = self.environment.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> V1Dag:
        """Create an instance of V1Dag from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return V1Dag.parse_obj(obj)

        _obj = V1Dag.parse_obj({
            "kind": obj.get("kind") if obj.get("kind") is not None else 'dag',
            "operations": [V1Operation.from_dict(_item) for _item in obj.get("operations")] if obj.get("operations") is not None else None,
            "components": [V1Component.from_dict(_item) for _item in obj.get("components")] if obj.get("components") is not None else None,
            "concurrency": obj.get("concurrency"),
            "early_stopping": obj.get("earlyStopping"),
            "environment": V1Environment.from_dict(obj.get("environment")) if obj.get("environment") is not None else None,
            "connections": obj.get("connections"),
            "volumes": obj.get("volumes")
        })
        return _obj




# coding: utf-8

"""
    Polyaxon SDKs and REST API specification.

         # noqa: E501

    The version of the OpenAPI document: 2.12.0-rc3
    Contact: contact@polyaxon.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel
from polyaxon_sdk.models.v1_hp_choice import V1HpChoice
from polyaxon_sdk.models.v1_hp_date_range import V1HpDateRange
from polyaxon_sdk.models.v1_hp_date_time_range import V1HpDateTimeRange
from polyaxon_sdk.models.v1_hp_geom_space import V1HpGeomSpace
from polyaxon_sdk.models.v1_hp_lin_space import V1HpLinSpace
from polyaxon_sdk.models.v1_hp_log_normal import V1HpLogNormal
from polyaxon_sdk.models.v1_hp_log_space import V1HpLogSpace
from polyaxon_sdk.models.v1_hp_log_uniform import V1HpLogUniform
from polyaxon_sdk.models.v1_hp_normal import V1HpNormal
from polyaxon_sdk.models.v1_hp_p_choice import V1HpPChoice
from polyaxon_sdk.models.v1_hp_q_log_normal import V1HpQLogNormal
from polyaxon_sdk.models.v1_hp_q_log_uniform import V1HpQLogUniform
from polyaxon_sdk.models.v1_hp_q_normal import V1HpQNormal
from polyaxon_sdk.models.v1_hp_q_uniform import V1HpQUniform
from polyaxon_sdk.models.v1_hp_range import V1HpRange
from polyaxon_sdk.models.v1_hp_uniform import V1HpUniform

class V1HpParams(BaseModel):
    """
    V1HpParams
    """
    choice: Optional[V1HpChoice] = None
    pchoice: Optional[V1HpPChoice] = None
    range: Optional[V1HpRange] = None
    linspace: Optional[V1HpLinSpace] = None
    logspace: Optional[V1HpLogSpace] = None
    geomspace: Optional[V1HpGeomSpace] = None
    uniform: Optional[V1HpUniform] = None
    quniform: Optional[V1HpQUniform] = None
    loguniform: Optional[V1HpLogUniform] = None
    qloguniform: Optional[V1HpQLogUniform] = None
    normal: Optional[V1HpNormal] = None
    qnormal: Optional[V1HpQNormal] = None
    lognormal: Optional[V1HpLogNormal] = None
    qlognormal: Optional[V1HpQLogNormal] = None
    daterange: Optional[V1HpDateRange] = None
    datetimerange: Optional[V1HpDateTimeRange] = None
    __properties = ["choice", "pchoice", "range", "linspace", "logspace", "geomspace", "uniform", "quniform", "loguniform", "qloguniform", "normal", "qnormal", "lognormal", "qlognormal", "daterange", "datetimerange"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> V1HpParams:
        """Create an instance of V1HpParams from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of choice
        if self.choice:
            _dict['choice'] = self.choice.to_dict()
        # override the default output from pydantic by calling `to_dict()` of pchoice
        if self.pchoice:
            _dict['pchoice'] = self.pchoice.to_dict()
        # override the default output from pydantic by calling `to_dict()` of range
        if self.range:
            _dict['range'] = self.range.to_dict()
        # override the default output from pydantic by calling `to_dict()` of linspace
        if self.linspace:
            _dict['linspace'] = self.linspace.to_dict()
        # override the default output from pydantic by calling `to_dict()` of logspace
        if self.logspace:
            _dict['logspace'] = self.logspace.to_dict()
        # override the default output from pydantic by calling `to_dict()` of geomspace
        if self.geomspace:
            _dict['geomspace'] = self.geomspace.to_dict()
        # override the default output from pydantic by calling `to_dict()` of uniform
        if self.uniform:
            _dict['uniform'] = self.uniform.to_dict()
        # override the default output from pydantic by calling `to_dict()` of quniform
        if self.quniform:
            _dict['quniform'] = self.quniform.to_dict()
        # override the default output from pydantic by calling `to_dict()` of loguniform
        if self.loguniform:
            _dict['loguniform'] = self.loguniform.to_dict()
        # override the default output from pydantic by calling `to_dict()` of qloguniform
        if self.qloguniform:
            _dict['qloguniform'] = self.qloguniform.to_dict()
        # override the default output from pydantic by calling `to_dict()` of normal
        if self.normal:
            _dict['normal'] = self.normal.to_dict()
        # override the default output from pydantic by calling `to_dict()` of qnormal
        if self.qnormal:
            _dict['qnormal'] = self.qnormal.to_dict()
        # override the default output from pydantic by calling `to_dict()` of lognormal
        if self.lognormal:
            _dict['lognormal'] = self.lognormal.to_dict()
        # override the default output from pydantic by calling `to_dict()` of qlognormal
        if self.qlognormal:
            _dict['qlognormal'] = self.qlognormal.to_dict()
        # override the default output from pydantic by calling `to_dict()` of daterange
        if self.daterange:
            _dict['daterange'] = self.daterange.to_dict()
        # override the default output from pydantic by calling `to_dict()` of datetimerange
        if self.datetimerange:
            _dict['datetimerange'] = self.datetimerange.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> V1HpParams:
        """Create an instance of V1HpParams from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return V1HpParams.parse_obj(obj)

        _obj = V1HpParams.parse_obj({
            "choice": V1HpChoice.from_dict(obj.get("choice")) if obj.get("choice") is not None else None,
            "pchoice": V1HpPChoice.from_dict(obj.get("pchoice")) if obj.get("pchoice") is not None else None,
            "range": V1HpRange.from_dict(obj.get("range")) if obj.get("range") is not None else None,
            "linspace": V1HpLinSpace.from_dict(obj.get("linspace")) if obj.get("linspace") is not None else None,
            "logspace": V1HpLogSpace.from_dict(obj.get("logspace")) if obj.get("logspace") is not None else None,
            "geomspace": V1HpGeomSpace.from_dict(obj.get("geomspace")) if obj.get("geomspace") is not None else None,
            "uniform": V1HpUniform.from_dict(obj.get("uniform")) if obj.get("uniform") is not None else None,
            "quniform": V1HpQUniform.from_dict(obj.get("quniform")) if obj.get("quniform") is not None else None,
            "loguniform": V1HpLogUniform.from_dict(obj.get("loguniform")) if obj.get("loguniform") is not None else None,
            "qloguniform": V1HpQLogUniform.from_dict(obj.get("qloguniform")) if obj.get("qloguniform") is not None else None,
            "normal": V1HpNormal.from_dict(obj.get("normal")) if obj.get("normal") is not None else None,
            "qnormal": V1HpQNormal.from_dict(obj.get("qnormal")) if obj.get("qnormal") is not None else None,
            "lognormal": V1HpLogNormal.from_dict(obj.get("lognormal")) if obj.get("lognormal") is not None else None,
            "qlognormal": V1HpQLogNormal.from_dict(obj.get("qlognormal")) if obj.get("qlognormal") is not None else None,
            "daterange": V1HpDateRange.from_dict(obj.get("daterange")) if obj.get("daterange") is not None else None,
            "datetimerange": V1HpDateTimeRange.from_dict(obj.get("datetimerange")) if obj.get("datetimerange") is not None else None
        })
        return _obj




# coding: utf-8

"""
    Polyaxon SDKs and REST API specification.

         # noqa: E501

    The version of the OpenAPI document: 2.12.0-rc3
    Contact: contact@polyaxon.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from inspect import getfullargspec
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class V1MatrixKind(str, Enum):
    """
    V1MatrixKind
    """

    """
    allowed enum values
    """
    RANDOM = 'random'
    GRID = 'grid'
    HYPERBAND = 'hyperband'
    BAYES = 'bayes'
    HYPEROPT = 'hyperopt'
    ITERATIVE = 'iterative'
    MAPPING = 'mapping'

